--[[ Gear Aug Checker by MrInfernal v1.0

/augcheck <empty/all> *<type# 1-22>*

ex: /augcheck empty
    /augcheck empty 9
    /augcheck all

Look through worn gear to return aug slots that are empty or tell you if they are empty/filled
Can sort by a type number

Close program with exit, close, or stop
ex: /augcheck stop
]]

--- @type Mq
local mq = require('mq')

local run = true

local gearSlotVis = {
    'head', -- 1
    'arms',
    'leftwrist',
    'rightwrist',
    'hands',  -- 5
    'chest',
    'legs',
    'feet',  -- 8
}

local gearSlotNonVis = {
    'leftear', -- 1
    'rightear',
    'face',
    'neck',
    'shoulder',  -- 5
    'back',
    'leftfinger',
    'rightfinger',
    'waist',
    'charm',  -- 10
}

local gearSlotWep = {
    'mainhand',
    'offhand',
    'ranged'
}

local function ShowHelp()
    print('Aug Checker by \arMrInfernal')
    print('\nUsage: /augcheck \ao<empty/all> \at<type# 1-22>')
    print('\aoEmpty \axor \aoAll \ax-- Only display empty slots or display as \aoEmpty/Filled')
    print('Aug Type #: \at1 \ax- \at22 \ax-- \ar(Optional) \axOnly search this slot type')
    --print('\nRun \ao/augcheck <augslot> \axwith an augment on cursor -- Check for slots that fit')
    print('\n \ao/augcheck help \ax-- Show this help message again\n')
end

local function runCheck(target, arg2)
    local typenum = tonumber(arg2)
    
    if target == 'exit' or target == 'stop' or target == 'close' then
        mq.unbind('/augcheck')
        run = false
    elseif target == 'help' then
        ShowHelp()
    -- Check all slots for type#
    elseif target == 'all' and typenum ~= nil and typenum > 0 and typenum <= 22 then
        printf('Displaying status of all type %d slots\n', typenum)
        for _, item in ipairs(gearSlotVis) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): Empty'
                            table.insert(gearSlots, aug)
                        elseif not gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): Filled'
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        for _, item in ipairs(gearSlotNonVis) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): Empty'
                            table.insert(gearSlots, aug)
                        elseif not gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): Filled'
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        for _, item in ipairs(gearSlotWep) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): Empty'
                            table.insert(gearSlots, aug)
                        elseif not gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): Filled'
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        print('\n')
    -- Empty type# slots
    elseif target == 'empty' and typenum ~= nil and typenum > 0 and typenum <= 22 then
        printf('Displaying empty type %d slots\n', typenum)
        for _, item in ipairs(gearSlotVis) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): Empty'
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        for _, item in ipairs(gearSlotNonVis) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): Empty'
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        for _, item in ipairs(gearSlotWep) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): Empty'
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        print('\n')
    -- Show Empty/Filled
    elseif target == 'all' then
    print('Displaying Fill status for all aug slots\n')
    for _, item in ipairs(gearSlotVis) do
        local gear = mq.TLO.Me.Inventory(item)
        local gearSlots = {}
        local itemName = item .. ': '
        if gear then
            for i=1, 6 do
                local gearType = gear.AugSlot(i).Type()
                if gearType > 2 then
                    if gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                        local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): Empty'
                        table.insert(gearSlots, aug)
                    elseif not gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                        local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): Filled'
                        table.insert(gearSlots, aug)
                    end
                end
            end
            if #gearSlots > 0 then
                print(itemName, table.concat(gearSlots, ','))
            end
        end
    end
    for _, item in ipairs(gearSlotNonVis) do
        local gear = mq.TLO.Me.Inventory(item)
        local gearSlots = {}
        local itemName = item .. ': '
        if gear then
            for i=1, 6 do
                local gearType = gear.AugSlot(i).Type()
                if gearType > 2 then
                    if gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                        local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): Empty'
                        table.insert(gearSlots, aug)
                    elseif not gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                        local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): Filled'
                        table.insert(gearSlots, aug)
                    end
                end
            end
            if #gearSlots > 0 then
                print(itemName, table.concat(gearSlots, ','))
            end
        end
    end
    for _, item in ipairs(gearSlotWep) do
        local gear = mq.TLO.Me.Inventory(item)
        local gearSlots = {}
        local itemName = item .. ': '
        if gear then
            for i=1, 6 do
                local gearType = gear.AugSlot(i).Type()
                if gearType > 2 then
                    if gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                        local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): Empty'
                        table.insert(gearSlots, aug)
                    elseif not gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                        local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): Filled'
                        table.insert(gearSlots, aug)
                    end
                end
            end
            if #gearSlots > 0 then
                print(itemName, table.concat(gearSlots, ','))
            end
        end
    end
    print('\n')
    else-- Default. Only show Empty
        print('Only displaying Empty aug slots\n')
        for _, item in ipairs(gearSlotVis) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): Empty'
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        for _, item in ipairs(gearSlotNonVis) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): Empty'
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        for _, item in ipairs(gearSlotWep) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): Empty'
                            table.insert(gearSlots, aug)
                        end
                    end
                end
            print(itemName, table.concat(gearSlots, ','))
            end
        end
        print('\n')
    end
end

ShowHelp()

mq.bind('/augcheck', runCheck)

while run do
    mq.delay(1000)
end